{% extends "page.html" %}
{% if announcement_login %}
  {% set announcement = announcement_login %}
{% endif %}

{% block login_widget %}
{% endblock %}

{% block main %}

{% block login %}
<div id="login-main" class="container">
{% if custom_html %}
{{ custom_html | safe }}
{% elif login_service %}
<div class="service-login">
  <a role="button" class='btn btn-jupyter btn-lg' href='{{authenticator_login_url}}'>
    Sign in with {{login_service}}
  </a>
</div>
{% else %}
<form action="{{login_url}}?next={{next}}" method="post" role="form">
  <div class="auth-form-header">
    {{hub_greeting_message}} 
  </div>
  <div class='auth-form-body'>

    <!-- <p id='insecure-login-warning' class='hidden'> -->
    <!-- Warning: JupyterHub seems to be served over an unsecured HTTP connection. -->
    <!-- We strongly recommend enabling HTTPS for JupyterHub. -->
    <!-- </p> -->

    {% if login_error %}
    <p class="login_error">
      {{login_error}}
    </p>
    {% endif %}
    <label for="username_input">Username:</label>
    <input
      id="username_input"
      type="text"
      autocapitalize="off"
      autocorrect="off"
      class="form-control"
      name="username"
      val="{{username}}"
      tabindex="1"
      autofocus="autofocus"
    />
    <label for='password_input'>Password:</label>
    <input
      type="password"
      class="form-control"
      name="password"
      id="password_input"
      tabindex="2"
    />
    {% if otp_required %}

    <label for=otp_input'>OTP:</label>
    <input
      type="text"
      class="form-control"
      name="otp"
      id="otp_input"
      tabindex="3"
    />
    {% endif %}

    <input
      type="submit"
      id="login_submit"
      class='btn btn-jupyter'
      value='Sign In'
      tabindex="4"
    />
  </div>
</form>
{% endif %}
</div>
{% endblock login %}

{% endblock %}

{% block script %}
{{ super() }}
<script>
if (window.location.protocol === "http:") {
  // unhide http warning
  var warning = document.getElementById('insecure-login-warning');
  warning.className = warning.className.replace(/\bhidden\b/, '');
}
</script>

{% endblock %}
